import { ContainerImage } from 'aws-cdk-lib/aws-ecs';
import { DockerImageCode } from 'aws-cdk-lib/aws-lambda';
import { Construct } from 'constructs';
/**
 * Properties for the `TokenInjectableDockerBuilder` construct.
 */
export interface TokenInjectableDockerBuilderProps {
    /**
     * The path to the directory containing the Dockerfile or source code.
     */
    readonly path: string;
    /**
     * Build arguments to pass to the Docker build process.
     * These are transformed into `--build-arg` flags.
     * @example
     * {
     *   TOKEN: 'my-secret-token',
     *   ENV: 'production'
     * }
     */
    readonly buildArgs?: {
        [key: string]: string;
    };
    /**
     * The ARN of the AWS Secrets Manager secret containing Docker login credentials.
     * This secret should store a JSON object with the following structure:
     * ```json
     * {
     *   "username": "my-docker-username",
     *   "password": "my-docker-password"
     * }
     * ```
     * If not provided, the construct will skip Docker login during the build process.
     *
     * @example 'arn:aws:secretsmanager:us-east-1:123456789012:secret:DockerLoginSecret'
     */
    readonly dockerLoginSecretArn?: string;
}
/**
 * A CDK construct to build and push Docker images to an ECR repository using CodeBuild and Lambda custom resources.
 */
export declare class TokenInjectableDockerBuilder extends Construct {
    private readonly ecrRepository;
    readonly containerImage: ContainerImage;
    readonly dockerImageCode: DockerImageCode;
    constructor(scope: Construct, id: string, props: TokenInjectableDockerBuilderProps);
}
